@@ -24,6 +24,8 @@ def main():
 
     console = get_console()
     console.print(f'Welcome to [bold]local-ci v{__version__}[/bold]', highlight=False, style='cyan')
+    console.print(f'For Python & Angular projects, make sure you are using the desired nvm and pyenv!',
+                  highlight=False, style='cyan')
     console.line(1)
 
     if args.platform == 'mvn':
