@@ -1,3 +1,4 @@
+import os
 from typing import Tuple
 
 from .cli_utils import get, call
@@ -5,13 +6,18 @@ from .platform_interface import Platform
 
 
 class Maven(Platform):
+    def check_if_valid(self) -> None:
+        if not os.path.isfile('pom.xml'):
+            self.console.print('Invalid Maven project in this directory.', style='bold red')
+            exit()
+
     def make(self) -> None:
         with self.console.status("[bold green] Building Maven project...") as status:
             self.check_for_changes(status)
 
             # Build with maven
             status.update(status='Building application package with Maven...')
-            call('mvn clean package')
+            call(self.console, 'mvn clean package')
 
             self.console.log(':white_check_mark: Built application package with Maven.')
 
